package com.muyu.marketing.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.marketing.domain.model.ActivityTeamProductSkuAddModel;
import com.muyu.marketing.domain.model.ActivityTeamProductSkuReqModel;
import com.muyu.marketing.domain.model.ActivityTeamProductSkuUpdModel;
import com.muyu.marketing.domain.req.TeamProjectSkuInfoAddReq;
import lombok.*;
import lombok.experimental.SuperBuilder;

import java.math.BigDecimal;

@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@TableName(value = "activity_team_product_sku_info", autoResultMap = true)
public class ActivityTeamProductSkuInfo extends BaseEntity {

  /**
   * 主键
   */
  @TableId(value = "id", type = IdType.AUTO)
  private long id;
  /**
   * 活动ID
   */
  private Long teamId;
  /**
   * 商品ID
   */
  private Long productId;
  /**
   * 商品SKU
   */
  private String productSku;
  /**
   * 拼团库存
   */
  private Long teamStock;
  /**
   * 剩余库存
   */
  private Long remainStock;
  /**
   * 拼团价格
   */
  private BigDecimal teamPrice;

  /**
   * 通过模型钢构件对象
   * @param activityTeamProductSkuAddModel 模型
   * @return 对象
   */
  public static ActivityTeamProductSkuInfo modelBuild(ActivityTeamProductSkuAddModel activityTeamProductSkuAddModel) {
    return ActivityTeamProductSkuInfo.builder()
            .productId(activityTeamProductSkuAddModel.getProductId())
            .teamId(activityTeamProductSkuAddModel.getTeamId())
            .teamStock(activityTeamProductSkuAddModel.getTeamStock())
            .productSku(activityTeamProductSkuAddModel.getSku())
            .remainStock(activityTeamProductSkuAddModel.getTeamStock())
            .teamPrice(activityTeamProductSkuAddModel.getTeamPrice())
            .build();
  }
  public static ActivityTeamProductSkuInfo updateModelBuild(ActivityTeamProductSkuReqModel activityTeamProductSkuReqModel) {
    return ActivityTeamProductSkuInfo.builder()
            .id(activityTeamProductSkuReqModel.getId())
            .productId(activityTeamProductSkuReqModel.getProductId())
            .teamStock(activityTeamProductSkuReqModel.getTeamStock())
            .productSku(activityTeamProductSkuReqModel.getProductSku())
            .teamPrice(activityTeamProductSkuReqModel.getTeamPrice())
            .build();
  }

  public static ActivityTeamProductSkuInfo updModelBuild(ActivityTeamProductSkuUpdModel activityTeamProductSkuUpdModel) {
    return ActivityTeamProductSkuInfo.builder()
            .id(activityTeamProductSkuUpdModel.getId())
            .teamPrice(activityTeamProductSkuUpdModel.getTeamPrice())
            .teamStock(activityTeamProductSkuUpdModel.getTeamStock())
            .remainStock(activityTeamProductSkuUpdModel.getTeamStock())
            .build();
  }

  public static ActivityTeamProductSkuInfo buildAddSku(TeamProjectSkuInfoAddReq teamProjectSkuInfoAddReq) {
    return ActivityTeamProductSkuInfo.builder()
            .teamId(teamProjectSkuInfoAddReq.getTeamId())
            .productId(teamProjectSkuInfoAddReq.getProductId())
            .productSku(teamProjectSkuInfoAddReq.getSku())
            .teamPrice(teamProjectSkuInfoAddReq.getTeamPrice())
            .teamStock(teamProjectSkuInfoAddReq.getTeamStock())
            .build();
  }

}
