package com.muyu.marketing.domain.model;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.marketing.domain.req.ActivityTeamInfoUpdReq;
import com.muyu.marketing.domain.req.ActivityTeamProductSkuUpdReq;
import com.muyu.marketing.domain.req.TeamProjectSkuInfoAddReq;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

/**
 * @program: 2204a-cloud-server
 * @description: 活动商品规格修改模型
 * @author: AoCi Tian
 * @create: 2024-11-26 19:25
 **/
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
public class ActivityTeamInfoUpdModel {

    /** 主键自增 */
    private Long id;

    /** 活动表名称 */
    private String name;

    /** 主键商品id */
    private Long productId;

    /** 商品图片 */
    private String productImage;

    /** 活动介绍 */
    private String introduction;

    /** 单位 */
    private String unit;

    /** 轮播图 */
    private String imageList;

    /** 结束时间 */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:ss:mm")
    @JsonFormat(pattern = "yyyy-MM-dd HH:ss:mm")
    private Date endTime;

    /** 排序 */
    private Long sort;

    /** 主键介绍 */
    private String content;

    /** 活动状态 */
    private String status;

    /** 策略类型 */
    private String strategyType;

    /** 策略id */
    private Long strategyId;

    /**
     * 拼团商品sku集合
     */
    private List<Long> teamProductSkuIds;

    /**
     * 修改的活动商品sku集合
     */
    private List<ActivityTeamProductSkuUpdReq> activityTeamProductSkuList;

    /**
     * 新增的活动商品sku集合
     */
    private List<TeamProjectSkuInfoAddReq> teamProjectSkuInfoAddList;

    public static ActivityTeamInfoUpdModel activityTeamInfoUpdReqModelBuild (ActivityTeamInfoUpdReq activityTeamInfoUpdReq){
        return ActivityTeamInfoUpdModel.builder()
                .id(activityTeamInfoUpdReq.getId())
                .name(activityTeamInfoUpdReq.getName())
                .productId(activityTeamInfoUpdReq.getProductId())
                .productImage(activityTeamInfoUpdReq.getProductImage())
                .introduction(activityTeamInfoUpdReq.getIntroduction())
                .unit(activityTeamInfoUpdReq.getUnit())
                .imageList(activityTeamInfoUpdReq.getImageList())
                .endTime(activityTeamInfoUpdReq.getEndTime())
                .sort(activityTeamInfoUpdReq.getSort())
                .content(activityTeamInfoUpdReq.getContent())
                .status(activityTeamInfoUpdReq.getStatus())
                .strategyType(activityTeamInfoUpdReq.getStrategyType())
                .strategyId(activityTeamInfoUpdReq.getStrategyId())
                .teamProductSkuIds(activityTeamInfoUpdReq.getTeamProductSkuIds())
                .activityTeamProductSkuList(activityTeamInfoUpdReq.getActivityTeamProductSkuList())
                .teamProjectSkuInfoAddList(activityTeamInfoUpdReq.getTeamProjectSkuInfoAddList())
                .build();
    }

}
